@@ -10,7 +10,7 @@ Copyright (C) 2008 Sergey Kirillov, Rainboo Software
  
 """
 
-__version__ = '2.0.6'
+__version__ = '2.0.7'
 
 import os
 import re
@@ -118,10 +118,12 @@ class LoopDevice(object):
         except:
             return False
     
-    def mount(self, target_path):
+    def mount(self, target_path, offset=0, sizelimit=0):
         """Mount file to loop device"""
         status = Status64()
         status.lo_filename = target_path
+        status.lo_offset = offset
+        status.lo_sizelimit = sizelimit
         
         self._do_mount(target_path, status)
 
